<?php

/**
 * Define the plugin settings
 *
 * @link       https://signatu.com
 * @since      1.0.0
 *
 * @package    Signatu
 * @subpackage Signatu/includes
 */

/**
 * Define the plugin settings.
 *
 *
 * @since      1.0.0
 * @package    Signatu
 * @subpackage Signatu/includes
 * @author     Signatu AS <wordpress@signatu.com>
 */


class Signatu_Settings {

	/**
	 * custom option and settings
	 */

	private $group_id_field = 'signatu_config_group_id';
	private $type_field = 'signatu_config_app_type';
	private $variant_field = 'signatu_config_variant';
	private $access_token_field = 'signatu_config_access_token';
	private $position_field = 'signatu_config_position';
	private $privacy_policy_field = 'signatu_config_privacy_policy';
	private $language_field = 'signatu_config_language';

	/** @todo the group can be changed if we want a custom page */
	private $page = 'signatu';
	private $section = 'signatu_settings_section';

	public function settings_init() {
		
		register_setting( $this->page, $this->access_token_field );
		register_setting( $this->page, $this->type_field );
		register_setting( $this->page, $this->language_field );
		register_setting( $this->page, $this->group_id_field );
		register_setting( $this->page, $this->variant_field );
		register_setting( $this->page, $this->position_field );
		register_setting( $this->page, $this->privacy_policy_field );

		add_settings_section(
			$this->section,
			'Cookie Banner', 
			array( $this, 'settings_name_callback' ) ,
			$this->page
		);
		add_settings_field(
			$this->access_token_field,
			"Access Token",
			array( $this, 'access_token_callback' ),
			$this->page,
			$this->section,
		);
		add_settings_field(
			$this->type_field,
			"Banner Type",
			array( $this, 'type_callback' ),
			$this->page,
			$this->section,
		);
		add_settings_field(
			$this->language_field,
			"Language",
			array( $this, 'language_callback' ),
			$this->page,
			$this->section,
		);
		add_settings_field(
			$this->group_id_field,
			"Data Processing Group ID",
			array( $this, 'group_id_callback' ),
			$this->page,
			$this->section,
		);
		add_settings_field(
			$this->privacy_policy_field,
			"Privacy Policy URL",
			array( $this, 'privacy_policy_callback' ),
			$this->page,
			$this->section,
		);
		add_settings_field(
			$this->variant_field,
			"Banner Variant",
			array( $this, 'variant_callback' ),
			$this->page,
			$this->section,
		);
		add_settings_field(
			$this->position_field,
			"Banner Position",
			array( $this, 'position_callback' ),
			$this->page,
			$this->section,
		);

	}

	public function admin_menu() {
		add_options_page(
			'Signatu Settings', 
			'Signatu', 
			'manage_options',
			$this->page,
			array($this, 'options_page')
		);
	}

	public function settings_name_callback() {
		echo '<p>Configure the Signatu Cookie Banner. Refer to the <a href="https://signatu.com/docs/guides/wordpress">plugin documentation</a> for additional information.</p>';
	}
	
	// field content cb
	public function access_token_callback() {
		$option = get_option($this->access_token_field);
		?>
		<input class="regular-text code" type="password" autocomplete="off" placeholder="Enter the OAuth token. Omit the trailing Bearer" name='<?php echo $this->access_token_field; ?>' value='<?php echo $option; ?>' />
    <?php
	}
	public function group_id_callback() {
		$option = get_option($this->group_id_field);
		?>
		<input class="regular-text code" type="text" placeholder="Enter the Group ID" name='<?php echo $this->group_id_field; ?>' value='<?php echo $option; ?>' />
    <?php
	}
	public function privacy_policy_callback() {
		$option = get_option($this->privacy_policy_field);
		?>
		<input class="regular-text code" type="text" placeholder="Privacy Policy URL" name='<?php echo $this->privacy_policy_field; ?>' value='<?php echo $option; ?>' />
    <?php
	}

	public function language_callback() {
		$option = get_option($this->language_field);
		?>
		<select name='<?php echo $this->language_field; ?>'>
				<option class="regular-text" value="en"  <?php if ( $option == 'en') { echo "selected"; } ?> > English </option>
				<option class="regular-text" value="no"  <?php if ( $option == 'no') { echo "selected"; } ?> > Norwegian (Bokmål)</option>
		</select>
    <?php
	}

	public function type_callback() {
		$option = get_option($this->type_field);
		?>
		<select name='<?php echo $this->type_field; ?>'>
				<option class="regular-text" value="cookie-button"  <?php if ( $option == 'cookie-button') { echo "selected"; } ?> > Cookie Button</option>
				<option class="regular-text" value="cookie-banner"  <?php if ( $option == 'cookie-banner') { echo "selected"; } ?> > Cookie Banner</option>
		</select>
    <?php
	}

	public function variant_callback() {
		$option = get_option($this->variant_field);
		?>
		<select name='<?php echo $this->variant_field; ?>'>
				<option class="regular-text" value="gdpr"  <?php if ( $option == 'gdpr') { echo "selected"; } ?> > GDPR </option>
				<option class="regular-text" value="ekom"  <?php if ( $option == 'ekom') { echo "selected"; } ?> > EKom (Norway)</option>
		</select>
    <?php
	}
	public function position_callback() {
		$option = get_option($this->position_field);
		?>
		<!-- <input class="regular-text code" placeholder="Position" name='<?php echo $this->position_field; ?>' value='<?php echo $option; ?>' /> -->
		<select name='<?php echo $this->position_field; ?>'>
				<option class="regular-text" value="top"  <?php if ( $option == 'top') { echo "selected"; } ?> > Top </option>
				<option class="regular-text" value="bottom"  <?php if ( $option == 'bottom') { echo "selected"; } ?> > Bottom </option>
				<option class="regular-text" value="center"  <?php if ( $option == 'bottom') { echo "selected"; } ?> > Center </option>
		</select>
    <?php
	}

	public function options_page() {
    // check user capabilities
    if ( ! current_user_can( 'manage_options' ) ) {
        return;
    }
		?>
		<div class="wrap">
			<h1><?php echo esc_html( get_admin_page_title() ); ?></h1>
			<form action="options.php" method="post">
				<?php
				settings_fields( $this->page );
				do_settings_sections( $this->page );
				submit_button( 'Save Settings' );
				?>
			</form>
		</div>
		<?php
	}
}


