<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://signatu.com
 * @since             0.113.4
 * @package           Signatu
 *
 * @wordpress-plugin
 * Plugin Name:       Signatu
 * Plugin URI:        https://signatu.com
 * Description:       Easy integration of a Signatu Cookie Banner in your Wordpress site.
 * Version:           0.121.0
 * Author:            Signatu AS
 * Author URI:        https://signatu.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       signatu
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'SIGNATU_SDK_VERSION', '0.121.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-signatu-activator.php
 */
function activate_signatu() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-signatu-activator.php';
	Signatu_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-signatu-deactivator.php
 */
function deactivate_signatu() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-signatu-deactivator.php';
	Signatu_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_signatu' );
register_deactivation_hook( __FILE__, 'deactivate_signatu' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-signatu.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_signatu() {

	$plugin = new Signatu();
	$plugin->run();

}
run_signatu();
